ezexl3 chat

Model No model ▼
Model Directory
GPU Auto (all GPUs)
Cache Size
Cache Quant
Loading model...

## Settings

Prompt Mode
System Prompt

## Sampling

Temperature
0.80
Top-K
50
Top-P
0.90
Min-P
0.00
Repetition Penalty
1.00
Max Response Tokens
1000

## Reasoning

Think mode
Suppress think tags
Think Budget

## Behavior

Amnesia mode
Banned Strings

## Session

## Model

Loading...
ezexl3 chat
✨
Send a message to start chatting
Auto-scroll Ctrl+Shift+Backspace = stop · Up = edit last